==> xcsoar-7.19.tar.xz: xcsoar-7.19/src/Tracking/LiveTrack24/Settings.hpp <==
/*
Copyright_License {

  XCSoar Glide Computer - http://www.xcsoar.org/
  Copyright (C) 2000-2021 The XCSoar Project
  A detailed list of copyright holders can be found in the file "AUTHORS".

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
}
*/

#ifndef XCSOAR_TRACKING_LIVETRACK24_SETTINGS_HPP
#define XCSOAR_TRACKING_LIVETRACK24_SETTINGS_HPP

#include "util/StaticString.hxx"

#include <tchar.h>

namespace LiveTrack24 {

struct Settings {
  enum class VehicleType {
    GLIDER = 0,
    PARAGLIDER = 1,
    POWERED_AIRCRAFT = 2,
    HOT_AIR_BALLOON = 3,
    HANGGLIDER_FLEX = 4,
    HANGGLIDER_RIGID = 5,
  };

  bool enabled;
  StaticString<64> server;
  StaticString<64> username;
  StaticString<64> password;

  /**
   * Tracking interval in seconds.
   */
  unsigned interval;

  VehicleType vehicleType;
  StaticString<64> vehicle_name;

  void SetDefaults() {
    enabled = false;
    server = _T("www.livetrack24.com");
    username.clear();
    password.clear();

    interval = 60;

    vehicleType = VehicleType::GLIDER;
  }
};

} /* namespace LiveTrack24 */

#endif

==> xcsoar-7.25.tar.xz: xcsoar-7.25/src/Tracking/LiveTrack24/Settings.hpp <==
/*
Copyright_License {

  XCSoar Glide Computer - http://www.xcsoar.org/
  Copyright (C) 2000-2022 The XCSoar Project
  A detailed list of copyright holders can be found in the file "AUTHORS".

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
}
*/

#pragma once

#include "util/StaticString.hxx"

#include <tchar.h>

namespace LiveTrack24 {

struct Settings {
  enum class VehicleType {
    GLIDER = 0,
    PARAGLIDER = 1,
    POWERED_AIRCRAFT = 2,
    HOT_AIR_BALLOON = 3,
    HANGGLIDER_FLEX = 4,
    HANGGLIDER_RIGID = 5,
  };

  bool enabled;
  StaticString<64> server;
  StaticString<64> username;
  StaticString<64> password;

  /**
   * Tracking interval in seconds.
   */
  unsigned interval;

  VehicleType vehicleType;
  StaticString<64> vehicle_name;

  void SetDefaults() {
    enabled = false;
    server = _T("www.livetrack24.com");
    username.clear();
    password.clear();

    interval = 60;

    vehicleType = VehicleType::GLIDER;
  }
};

} /* namespace LiveTrack24 */
